@@ -3,6 +3,7 @@ package App::Netdisco::Web::Plugin::AdminTask::JobQueue;
 use Dancer ':syntax';
 use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
+use Dancer::Plugin::Auth::Extensible;
 
 use App::Netdisco::Web::Plugin;
 
@@ -11,8 +12,7 @@ register_admin_task({
   label => 'Job Queue',
 });
 
-ajax '/ajax/control/admin/jobqueue/del' => sub {
-    send_error('Forbidden', 403) unless var('user')->admin;
+ajax '/ajax/control/admin/jobqueue/del' => require_role admin => sub {
     send_error('Missing job', 400) unless param('job');
 
     schema('netdisco')->txn_do(sub {
@@ -21,17 +21,13 @@ ajax '/ajax/control/admin/jobqueue/del' => sub {
     });
 };
 
-ajax '/ajax/control/admin/jobqueue/delall' => sub {
-    send_error('Forbidden', 403) unless var('user')->admin;
-
+ajax '/ajax/control/admin/jobqueue/delall' => require_role admin => sub {
     schema('netdisco')->txn_do(sub {
       my $device = schema('netdisco')->resultset('Admin')->delete;
     });
 };
 
-ajax '/ajax/content/admin/jobqueue' => sub {
-    send_error('Forbidden', 403) unless var('user')->admin;
-
+ajax '/ajax/content/admin/jobqueue' => require_role admin => sub {
     my $set = schema('netdisco')->resultset('Admin')
       ->with_times
       ->search({}, {
